@@ -13,10 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
 
 import base64
 import logging
-from typing import Dict
 
 from aiohomekit import exceptions
 from aiohomekit.controller import Controller
@@ -26,6 +26,7 @@ from aiohomekit.exceptions import AccessoryNotFoundError
 from aiohomekit.model import Accessories
 from aiohomekit.model.characteristics import CharacteristicsTypes
 from aiohomekit.protocol.statuscodes import HapStatusCode
+from aiohomekit.uuid import normalize_uuid
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -37,7 +38,7 @@ FAKE_CAMERA_IMAGE = (
 
 class FakeDiscovery:
     def __init__(
-        self, controller: "FakeController", device_id: str, accessories: Accessories
+        self, controller: FakeController, device_id: str, accessories: Accessories
     ):
         self.controller = controller
         self.device_id = device_id
@@ -108,14 +109,13 @@ class PairingTester:
         self.characteristics = {}
         self.services = {}
 
-        name_uuid = CharacteristicsTypes.get_uuid(CharacteristicsTypes.NAME)
         for accessory in self.pairing.accessories:
             for service in accessory.services:
                 service_map = {}
                 for char in service.characteristics:
                     self.characteristics[(accessory.aid, char.iid)] = char
                     service_map[char.type] = char
-                    if char.type == name_uuid:
+                    if char.type == CharacteristicsTypes.NAME:
                         self.services[char.get_value()] = service_map
 
     def set_events_enabled(self, value):
@@ -126,7 +126,7 @@ class PairingTester:
         Finds a named service then sets characteristics by type.
 
         pairing.test.update_named_service("kitchen lamp", {
-            CharacteristicTypes.ON: True
+            CharacteristicsTypes.ON: True
         })
 
         Triggers events if enabled.
@@ -138,7 +138,7 @@ class PairingTester:
 
         changed = []
         for uuid, value in new_values.items():
-            uuid = CharacteristicsTypes.get_uuid(uuid)
+            uuid = normalize_uuid(uuid)
 
             if uuid not in service:
                 raise RuntimeError(
@@ -195,7 +195,7 @@ class FakePairing(AbstractPairing):
         self.connection.transport = "mock_transport"
         self.connection.protocol = "mock_protocol"
         self.accessories = accessories
-        self.pairing_data: Dict[str, AbstractPairing] = {}
+        self.pairing_data: dict[str, AbstractPairing] = {}
         self.available = True
 
         self.testing = PairingTester(self)
